@@ -12,5 +12,5 @@ echo "  exit 1" >>$1
 echo "fi" >>$1
 echo "PATH=/usr/lib/fjsdk/bin:\${PATH}" >>$1
 echo "export PATH" >>$1
-echo "exec $2 \"\$@\"" >>$1
-chmod +x $1
\ No newline at end of file
+echo "exec $2 \$@" >>$1
+chmod +x $1
